import os
import pyarrow.parquet as pq
import csv

def list_tables_and_columns(base_path, output_file):
    unique_entries = set()
    with open(output_file, 'w', newline='') as csvfile:
        csvwriter = csv.writer(csvfile)
        for device_name in os.listdir(base_path):
            device_path = os.path.join(base_path, device_name)
            if os.path.isdir(device_path):
                for table_name in os.listdir(device_path):
                    table_path = os.path.join(device_path, table_name)
                    if os.path.isdir(table_path):
                        # Find the first parquet file in this table's directory
                        for root, dirs, files in os.walk(table_path):
                            for file in files:
                                if file.endswith('.parquet'):
                                    file_path = os.path.join(root, file)
                                    # Read the parquet file to get column names
                                    try:
                                        parquet_file = pq.ParquetFile(file_path)
                                        for column in parquet_file.schema.names:
                                            if column != "t":  # Skip columns named "t"
                                                entry = (device_name, table_name, column)
                                                if entry not in unique_entries:
                                                    unique_entries.add(entry)
                                                    csvwriter.writerow(entry)
                                    except Exception as e:
                                        print(f"Error reading {file_path}: {e}")
                                    break  # Only process the first parquet file per table

# Replace 'datalake' with the path to your data lake
list_tables_and_columns('datalake', 'mapping_table.csv')
